# metatree

[![PyPI](https://img.shields.io/pypi/v/metatree)](https://pypi.org/project/metatree/)
![Conda (channel only)](https://img.shields.io/conda/vn/bioconda/metatree?color=green)

Visualisation of polyphyletic groups between phylogenetic trees to a given reference tree.


## Installation
* PyPI: `pip install metatree`
* conda: `conda install -c bioconda metatree`


## Usage

```shell script
metatree [batchfile] [out_dir] [taxonomy_file] [outgroup] [cpus]
```

See the [example](https://github.com/aaronmussig/metatree/blob/master/example/index.md) directory for an example on how to use `metatree`.


## Changelog
```
0.0.1
  - Initial release.
```
